/**
 * crype
 *
 */

#include "ccrype.h"

enum crype_cli_mode {
	CCM_UNKNOWN,
	CCM_ENCRYPT,
	CCM_DECRYPT
};

int usage() {
	fputs(
		"Usage: crype [options]\n"
		"\n"
		"  -e                      Encrypt\n"
		"  -d                      Decrypt\n"
		"  -i {file}               Set input from file (default stdin)\n"
		"  -o {file}               Set output to file (default stdout)\n"
		"  --password {str}        Set encryption password\n"
		"  --password-file {file}  Read encryption password from file\n"
		"  -v                      Verbose\n"
		,
		stderr
	);
	return 1;
}

int main(int argc, char** argv) {
	
	/*
	Test args (A+S+5)

	-e -i input.dat -o output3.dat --password "asdf"
	*/

	std::string pass_str = "";
	enum crype_cli_mode climode = CCM_UNKNOWN;
	bool verbose = false;

	crype c;

	for (int i = 1; i < argc; ++i) {
		if (!strcmp(argv[i], "-e")) {
			climode = CCM_ENCRYPT;

		} else if (!strcmp(argv[i], "-d")) {
			climode = CCM_DECRYPT;

		} else if (!strcmp(argv[i], "-i")) {
			c.in = fopen(argv[++i], "rb");
			if (c.in == NULL) {
				fprintf(stderr, "Error opening \"%s\" for input\n", argv[i]);
				return 1;
			}

		} else if (!strcmp(argv[i], "-o")) {
			c.out = fopen(argv[++i], "wb");
			if (c.out == NULL) {
				fprintf(stderr, "Error opening \"%s\" for output\n", argv[i]);
			}

		} else if (!strcmp(argv[i], "--password")) {
			pass_str.assign(argv[++i]);

		} else if (!strcmp(argv[i], "--password-file")) {
			fputs("crype: not implemented", stderr);
			return 1;

		} else if (!strcmp(argv[i], "-v")) {
			verbose = true;

		} else {
			fprintf(stderr, "Unrecognised option \"%s\"\n\n", argv[i]);
			return usage();

		}
	}

	if (!pass_str.length()) {
		fputs("crype: No password specified\n", stderr);
		return 1;
	}

	c.set_encryption_key(pass_str);

	switch (climode) {
		case CCM_ENCRYPT: {
			c.encrype();
		} break;

		case CCM_DECRYPT: {
			c.decrype();
		} break;

		default:
		case CCM_UNKNOWN:
			return usage();
	}

	if (verbose) {
		fprintf(stderr, "crype: Processed %d chain(s)\n", c.total_chains);
	}

	return 0;
}
